<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>CircleCP</name>
    <message>
        <location filename="../CircleCP.js" line="+56"/>
        <source>Center</source>
        <translation>中心</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Point on circle or radius</source>
        <translation>圆或半径上的点</translation>
    </message>
    <message>
        <location filename="../CircleCPInit.js" line="+2"/>
        <source>&amp;Center, Point</source>
        <translation>圆心，点</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw circle from center and point on circle</source>
        <translation>由圆心和圆上的点画圆</translation>
    </message>
</context>
</TS>
